pub struct DCParameter {
base_type: DCTypeDefinition,
identifier: Option<String>,
default_value: Vec<u8>,
}Expand description
Represents the type specification of a parameter, which can live under an atomic field, or become a standalone parameter field. (e.g. for structs)
Fields
base_type: DCTypeDefinitionidentifier: Option<String>default_value: Vec<u8>Implementations
Sourceimpl DCParameter
impl DCParameter
pub fn has_identifier(&self) -> bool
pub fn has_default_value(&self) -> bool
pub fn get_default_value(&self) -> &Vec<u8> ⓘ